pub enum DetachReplayStatus {
Parked,
InFlight,
Superseded,
LeaveSuperseded,
Terminal(DetachReplayTerminal),
}Expand description
Closed, lossless detach replay status vocabulary.
Variants
Parked
The exact detach is durably parked for a transport attempt.
InFlight
A transport attempt is outstanding.
Superseded
A matching newer attach permanently superseded the old detach.
LeaveSuperseded
A matching durable Leave permanently superseded the old detach.
Terminal(DetachReplayTerminal)
A typed server result terminalized replay.