pub fn apply_attach(
aggregate: ClientParticipantAggregate,
attach: AttachBound,
correlation: ClientResponseCorrelation,
) -> ApplyAttachDecisionExpand description
Applies attach supersession without treating attach as transport fate.
pub fn apply_attach(
aggregate: ClientParticipantAggregate,
attach: AttachBound,
correlation: ClientResponseCorrelation,
) -> ApplyAttachDecisionApplies attach supersession without treating attach as transport fate.