pub fn decide_inbound(
aggregate: ClientParticipantAggregate,
value: ServerValue,
) -> ClientInboundDecisionExpand description
Correlates and applies one server value inside the client aggregate.
pub fn decide_inbound(
aggregate: ClientParticipantAggregate,
value: ServerValue,
) -> ClientInboundDecisionCorrelates and applies one server value inside the client aggregate.