pub const fn record_explicit_reconnect(
aggregate: ClientParticipantAggregate,
action: ExplicitReconnectAction,
) -> ReconnectPermitDecisionExpand description
Records explicit caller action and mints at most one permit.
pub const fn record_explicit_reconnect(
aggregate: ClientParticipantAggregate,
action: ExplicitReconnectAction,
) -> ReconnectPermitDecisionRecords explicit caller action and mints at most one permit.