pub enum AggregateOperationFaultReason {
DetachTerminalCellMismatch,
LeaveIdentityNotRetired,
}Expand description
Reason a consumed typed commit could not repeat itself as an event body.
Variants
DetachTerminalCellMismatch
The detach transition’s committed terminal and replay cell did not name one detach commit.
LeaveIdentityNotRetired
The leave commit’s identity result was not a permanent tombstone.