pub enum MarkerAckCommitError {
Conversation {
expected: ConversationId,
actual: ConversationId,
},
Participant {
expected: ParticipantId,
actual: ParticipantId,
},
Generation {
expected: Generation,
actual: Generation,
},
NonAdvancing {
from_cursor: DeliverySeq,
resulting_cursor: DeliverySeq,
},
CursorPrestate {
expected_from_cursor: DeliverySeq,
resulting_cursor: DeliverySeq,
actual_cursor: DeliverySeq,
},
}Expand description
Failure while applying an already-selected marker-ack commit.
Variants
Conversation
Commit belongs to another conversation.
Fields

expected: ConversationIdConversation captured by the commit.

actual: ConversationIdConversation carried by the supplied member.
Participant
Commit belongs to another participant.
Fields

expected: ParticipantIdParticipant captured by the commit.

actual: ParticipantIdParticipant carried by the supplied member.
Generation
Commit belongs to another credential generation.
Fields

expected: GenerationGeneration captured by the commit.

actual: GenerationGeneration carried by the supplied member.
NonAdvancing
A malformed internal update did not strictly advance its source cursor.
Fields

from_cursor: DeliverySeqCursor from which the update was selected.

resulting_cursor: DeliverySeqProposed resulting cursor.
CursorPrestate
Supplied member is neither the exact old nor exact committed prestate.
Fields

expected_from_cursor: DeliverySeqCursor from which the commit was selected.

resulting_cursor: DeliverySeqCursor produced by the commit.

actual_cursor: DeliverySeqCursor carried by the supplied member.