pub enum MarkerProvenance {
NonProductM,
TerminalProduct {
terminal: TerminalProductSource,
affected_participant: ParticipantId,
},
ExitProduct {
exit_participant: ParticipantId,
remaining_participant: ParticipantId,
},
}Expand description
Immutable origin of one planned or appended marker value.
Variants
NonProductM
Marker was planned directly by an optional floor transition.
TerminalProduct
Marker was conditionally reserved by a terminal product.
Fields

terminal: TerminalProductSourceExact causal terminal source.

affected_participant: ParticipantIdPermanent affected participant index.
ExitProduct
Marker was conditionally reserved by a membership-exit product.
Fields

exit_participant: ParticipantIdExiting participant whose E claim caused the product.

remaining_participant: ParticipantIdRemaining participant the possible marker protects.
Implementations
Sourceimpl MarkerProvenance
impl MarkerProvenance
Sourcepub const fn terminal_product(
terminal: TerminalProductSource,
affected_participant: ParticipantId,
) -> Self
pub const fn terminal_product( terminal: TerminalProductSource, affected_participant: ParticipantId, ) -> Self
Names one conditional terminal-product marker provenance.
Sourcepub const fn exit_product(
exit_participant: ParticipantId,
remaining_participant: ParticipantId,
) -> Self
pub const fn exit_product( exit_participant: ParticipantId, remaining_participant: ParticipantId, ) -> Self
Names one conditional membership-exit-product marker provenance.