pub enum MintFencedAttachResult {
Minted(Box<MintedFencedAttach>),
MintRefused(Box<MintFencedAttachRefused>),
}Expand description
Complete result of the sole production fenced proof mint.
Variants
Minted(Box<MintedFencedAttach>)
Exactly one marker authority was spent and one proof was minted.
MintRefused(Box<MintFencedAttachRefused>)
No proof was minted; the same authority and inputs are serially retryable.