pub enum NonzeroParticipantAckCommitError {
Conversation {
expected: ConversationId,
actual: ConversationId,
},
Participant {
expected: ParticipantId,
actual: ParticipantId,
},
Generation {
expected: Generation,
actual: Generation,
},
EpisodePrestate,
AggregateCursorPrestate {
episode_position: NonzeroAckEpisodePosition,
expected_cursor: DeliverySeq,
actual_cursor: DeliverySeq,
},
NonAdvancing {
from_cursor: DeliverySeq,
resulting_cursor: DeliverySeq,
},
CursorPrestate {
expected_from_cursor: DeliverySeq,
resulting_cursor: DeliverySeq,
actual_cursor: DeliverySeq,
},
}Expand description
Failure while applying an already-selected nonzero-debt ack commit.
Variants
Conversation
Commit belongs to another conversation.
Fields
expected: ConversationIdConversation captured by the commit.
actual: ConversationIdConversation carried by the supplied member.
Participant
Commit belongs to another participant.
Fields
expected: ParticipantIdParticipant captured by the commit.
actual: ParticipantIdParticipant carried by the supplied member.
Generation
Commit belongs to another credential generation.
Fields
expected: GenerationGeneration captured by the commit.
actual: GenerationGeneration carried by the supplied member.
EpisodePrestate
Supplied episode is neither the exact old nor exact resulting state.
AggregateCursorPrestate
Member cursor disagrees with the supplied old/resulting episode state.
Fields
episode_position: NonzeroAckEpisodePositionWhich exact episode state was supplied.
expected_cursor: DeliverySeqCursor required by that episode position.
actual_cursor: DeliverySeqCursor carried by the supplied member.
NonAdvancing
A malformed internal update did not strictly advance its source cursor.
Fields
from_cursor: DeliverySeqCursor from which the update was selected.
resulting_cursor: DeliverySeqProposed resulting cursor.
CursorPrestate
The opaque member update disagreed with the already-validated pair.
Fields
expected_from_cursor: DeliverySeqCursor from which the commit was selected.
resulting_cursor: DeliverySeqCursor produced by the commit.
actual_cursor: DeliverySeqCursor carried by the supplied member.