NonzeroParticipantAckInvariantError

Enum NonzeroParticipantAckInvariantError 

pub enum NonzeroParticipantAckInvariantError {
    Conversation {
        member: ConversationId,
        episode: ConversationId,
    },
    ParticipantMissing {
        participant_id: ParticipantId,
    },
    Generation {
        member: Generation,
        episode: Generation,
    },
    Cursor {
        member: DeliverySeq,
        episode: DeliverySeq,
    },
    BindingEpoch {
        active: BindingEpoch,
        episode: BindingEpoch,
    },
    EpisodeTransition(CumulativeAckAuthorizationError),
}
Durable aggregate mismatch found after common request authority succeeded.

Variants



Conversation

Episode belongs to another conversation.

Fields

member: ConversationId

Conversation owned by the selected member.

episode: ConversationId

Conversation owned by the episode.



ParticipantMissing

Episode has no entry for the selected permanent participant index.

Fields

participant_id: ParticipantId

Selected participant identifier/index.



Generation

Episode entry carries another credential generation.

Fields

member: Generation

Current member generation.

episode: Generation

Generation carried by the episode binding epoch.



Cursor

Episode entry cursor differs from durable membership.

Fields

member: DeliverySeq

Durable member cursor.

episode: DeliverySeq

Episode entry cursor.



BindingEpoch

Episode entry carries another active binding epoch.

Fields

active: BindingEpoch

Exact binding authorized by common lookup.

episode: BindingEpoch

Binding epoch carried by the episode entry.



EpisodeTransition(CumulativeAckAuthorizationError)

Existing episode transition rejected an otherwise-validated aggregate.