pub enum RecipientAckObligationsContextError {
Participant {
expected: ParticipantId,
actual: ParticipantId,
},
AcknowledgedThrough {
expected: DeliverySeq,
actual: DeliverySeq,
},
}Expand description
The testimony belongs to another participant or durable ack prestate.
Variants
Participant
The testimony names another permanent participant.
Fields

expected: ParticipantIdParticipant required by the authorized request.

actual: ParticipantIdParticipant carried by the testimony.
AcknowledgedThrough
The testimony was sealed against another durable ack frontier.
Fields

expected: DeliverySeqCursor required by the authorized request prestate.

actual: DeliverySeqCursor carried by the testimony.