pub enum RetirementError {
Conversation,
Participant,
Generation,
RetiredGeneration,
Token,
LeftAdmissionOrder,
}Expand description
Mismatch between a live member and proposed stored Leave result.
Variants
Conversation
Result names another conversation.
Participant
Result names another participant.
Generation
Result’s presented generation differs from current generation.
RetiredGeneration
Result’s retired generation differs from the current live generation.
Token
Result’s Leave token differs from the committing token.
LeftAdmissionOrder
Stored Left order is not phase 1 for the retired participant.