apply_enrollment_frontier

Function apply_enrollment_frontier 

pub fn apply_enrollment_frontier<F>(
    owner: LiveFrontierOwner,
    operation: EnrollmentCommit<F>,
    attached_charge: RetainedRecordCharge,
) -> LiveFrontierResult<EnrollmentCommit<F>>
Applies a subsequent enrollment to the complete live owner.

Errors

Returns a failure retaining the unchanged owner and intact enrollment commit.