commit_enrollment

Function commit_enrollment 

pub fn commit_enrollment<F, P>(
    request: &EnrollmentRequest,
    parameters: EnrollmentCommitParameters<F, P>,
) -> Result<EnrollmentCommit<F>, EnrollmentCommitError>
Atomically creates membership, binding, Attached, and canonical receipt.

Errors

Returns EnrollmentCommitError when the consumed allocator proof and request disagree or the result binding is not generation one.