pub struct AggregateOperationRefusal<T> { /* private fields */ }Expand description
Refused aggregate decision retaining the unchanged shell and the intact consumed operation commit.
Implementations
Sourceimpl<T> AggregateOperationRefusal<T>
impl<T> AggregateOperationRefusal<T>
Sourcepub const fn reason(&self) -> ConversationRefusalReason
pub const fn reason(&self) -> ConversationRefusalReason
Returns the shell’s stable refusal reason.
Sourcepub fn into_parts(self) -> (ParticipantConversation, T)
pub fn into_parts(self) -> (ParticipantConversation, T)
Recovers the unchanged shell and the intact operation commit.