pub struct AttachedRecordPosition { /* private fields */ }Expand description
Assigned ordering and delivery position of one Attached lifecycle record.
Implementations
Sourceimpl AttachedRecordPosition
impl AttachedRecordPosition
Sourcepub const fn new(
transaction_order: TransactionOrder,
delivery_seq: DeliverySeq,
) -> Self
pub const fn new( transaction_order: TransactionOrder, delivery_seq: DeliverySeq, ) -> Self
Creates the committed position allocated by the conversation lane.
Sourcepub const fn transaction_order(self) -> TransactionOrder
pub const fn transaction_order(self) -> TransactionOrder
Returns the assigned transaction-order major.
Sourcepub const fn delivery_seq(self) -> DeliverySeq
pub const fn delivery_seq(self) -> DeliverySeq
Returns the assigned delivery sequence.