pub struct BoundParticipantCursor { /* private fields */ }Expand description
One currently bound participant’s durable cumulative-cursor state.
All fields are private so cursor advancement can occur only through the monotonic cumulative-ack transition below.
Implementations
Sourceimpl BoundParticipantCursor
impl BoundParticipantCursor
Sourcepub const fn new(
participant_id: ParticipantId,
active_binding_epoch: BindingEpoch,
cursor: DeliverySeq,
) -> Self
pub const fn new( participant_id: ParticipantId, active_binding_epoch: BindingEpoch, cursor: DeliverySeq, ) -> Self
Creates one bound participant cursor at its already-durable position.
Sourcepub const fn participant_index(self) -> ParticipantIndex
pub const fn participant_index(self) -> ParticipantIndex
Returns the participant’s permanent index.
Sourcepub const fn participant_id(self) -> ParticipantId
pub const fn participant_id(self) -> ParticipantId
Returns the participant’s permanent identifier.
Sourcepub const fn active_binding_epoch(self) -> BindingEpoch
pub const fn active_binding_epoch(self) -> BindingEpoch
Returns the binding epoch authorized to advance this cursor.
Sourcepub const fn cursor(self) -> DeliverySeq
pub const fn cursor(self) -> DeliverySeq
Returns the durable cumulative cursor.