pub struct CommittedDetach<V> { /* private fields */ }Expand description
Committed detach replay cell with its real Detached record sequence.
Implementations
Sourceimpl<V: Copy + Eq> CommittedDetach<V>
impl<V: Copy + Eq> CommittedDetach<V>
Sourcepub fn verify_exact(
&self,
request: &DetachRequest,
request_verifier: V,
) -> Result<VerifiedCommittedDetach<'_, V>, DetachReplayError>
pub fn verify_exact( &self, request: &DetachRequest, request_verifier: V, ) -> Result<VerifiedCommittedDetach<'_, V>, DetachReplayError>
Verifies exact replay against the stored token, request fields, and verifier.
Errors
Returns DetachReplayError at the first mismatch.