pub struct EnrollmentLiveReceipt { /* private fields */ }Expand description
Stored secret-bearing enrollment receipt while its receipt deadline is live.
Implementations
Sourceimpl EnrollmentLiveReceipt
impl EnrollmentLiveReceipt
Sourcepub const fn from_commit(committed: EnrollBound) -> Self
pub const fn from_commit(committed: EnrollBound) -> Self
Captures the exact committed enrollment payload as a live receipt.