pub struct FrontierParticipant { /* private fields */ }Expand description
Participant-indexed membership fact used by claim validation and planning.
Implementations
Sourceimpl FrontierParticipant
impl FrontierParticipant
Sourcepub const fn new(
participant_index: ParticipantId,
cursor: DeliverySeq,
binding: FrontierBinding,
) -> Self
pub const fn new( participant_index: ParticipantId, cursor: DeliverySeq, binding: FrontierBinding, ) -> Self
Creates one exact live-membership frontier fact.
Sourcepub const fn participant_index(self) -> ParticipantId
pub const fn participant_index(self) -> ParticipantId
Returns the permanent participant index.
Sourcepub const fn cursor(self) -> DeliverySeq
pub const fn cursor(self) -> DeliverySeq
Returns the durable cumulative cursor.
Sourcepub const fn binding(self) -> FrontierBinding
pub const fn binding(self) -> FrontierBinding
Returns the exact current or last authoritative binding state.