pub struct MarkerProofPermit { /* private fields */ }Expand description
Opaque authority for an exact delivered marker and originating operation.
Implementations
Sourceimpl MarkerProofPermit
impl MarkerProofPermit
Sourcepub const fn operation(&self) -> &MarkerProofInput
pub const fn operation(&self) -> &MarkerProofInput
Returns the exact operation authorized by this proof.
Sourcepub const fn expected_marker_delivery_seq(&self) -> DeliverySeq
pub const fn expected_marker_delivery_seq(&self) -> DeliverySeq
Returns the exact expected and delivered marker sequence.
Sourcepub const fn proof_binding_epoch(&self) -> BindingEpoch
pub const fn proof_binding_epoch(&self) -> BindingEpoch
Returns the binding epoch against which delivery was proven.
Sourcepub const fn progress(&self) -> ParticipantCursorProgress
pub const fn progress(&self) -> ParticipantCursorProgress
Returns the retained marker-backed cursor provenance.