pub struct MintedFencedAttach { /* private fields */ }Expand description
Successful one-use fenced proof mint.
Implementations
Sourceimpl MintedFencedAttach
impl MintedFencedAttach
Sourcepub fn into_parts(self) -> (LiveFrontierOwner, FencedAttachCommit)
pub fn into_parts(self) -> (LiveFrontierOwner, FencedAttachCommit)
Consumes the result into the owner with spent marker authority and the sole proof admitted to the downstream by-value chain.