pub struct RecordSizePermit { /* private fields */ }Expand description
Successful static ordinary-record size preflight.
The exact encoded charge is carried forward so a later protocol operation does not need to recompute or substitute the value that passed stage 8.
Implementations
Sourceimpl RecordSizePermit
impl RecordSizePermit
Sourcepub const fn encoded_record_charge(self) -> ResourceVector
pub const fn encoded_record_charge(self) -> ResourceVector
Returns the exact encoded charge that passed both component limits.