pub struct ServerIncarnationFsyncIntent { /* private fields */ }Expand description
Checked startup write which must be fsynced before participant mode starts.
Implementations
Sourceimpl ServerIncarnationFsyncIntent
impl ServerIncarnationFsyncIntent
Sourcepub const fn prior_server_incarnation(&self) -> u64
pub const fn prior_server_incarnation(&self) -> u64
Returns the durable counter value from before this startup.
Sourcepub const fn server_incarnation(&self) -> u64
pub const fn server_incarnation(&self) -> u64
Returns the checked server incarnation to persist and fsync.
Sourcepub const fn header_to_fsync(&self) -> ConnectionIncarnationAllocatorRestore
pub const fn header_to_fsync(&self) -> ConnectionIncarnationAllocatorRestore
Returns the exact fresh-ordinal header to persist and fsync.
Sourcepub const fn complete_after_fsync(self) -> ConnectionIncarnationAllocator
pub const fn complete_after_fsync(self) -> ConnectionIncarnationAllocator
Releases the current allocator after the server has persisted and fsynced
Self::header_to_fsync in its startup transaction.