ParkingShapeViolation

Enum ParkingShapeViolation 

pub enum ParkingShapeViolation {
    NonzeroLimit {
        field: ParkingLimitField,
        actual: u64,
        required_minimum: u64,
    },
    RecoveryEntrySchemaBytes {
        actual: u64,
        required: u64,
    },
    WireSchemaBytes {
        actual: u64,
        required: u64,
    },
    RequestSchemaBytes {
        configured_request_limit: u64,
        wire_frame_limit: u64,
        actual: u64,
        required: u64,
    },
    RowSchemaBytes {
        request_limit: u64,
        row_metadata_bytes: u64,
        actual: u64,
        required: u128,
    },
    CheckedProduct(CheckedMultiplyOverflow),
    RowBytesBound {
        left: u64,
        right: u64,
        checked_product: u64,
        actual: u64,
    },
    SdkBytesBound {
        left: u64,
        right: u64,
        checked_product: u64,
        actual: u64,
    },
    RecoverableSlots {
        actual: u64,
        limit: u64,
    },
}
Exact nine-way parking configuration-shape violation.

Variants



NonzeroLimit

One of the signed limits is zero.

Fields

field: ParkingLimitField

Offending signed field.

actual: u64

Actual value, which is zero for this variant.

required_minimum: u64

Required minimum, which is one for this variant.



RecoveryEntrySchemaBytes

Recovery request-entry schema is not the fixed width.

Fields

actual: u64

Configured request-entry width.

required: u64

Required request-entry width of sixteen bytes.



WireSchemaBytes

Wire frame is too small for one participant frame.

Fields

actual: u64

Configured wire-frame limit.

required: u64

Required participant-frame schema bytes.



RequestSchemaBytes

Effective request limit is too small for one request schema.

Fields

configured_request_limit: u64

Configured participant request limit.

wire_frame_limit: u64

Configured wire-frame limit.

actual: u64

Effective request limit min(R, WF).

required: u64

Required participant-request schema bytes.



RowSchemaBytes

Charged row bound is below request plus row metadata.

Fields

request_limit: u64

Configured participant request limit.

row_metadata_bytes: u64

Fixed row-metadata bytes.

actual: u64

Configured charged row byte bound.

required: u128

Exact widened required bytes.



CheckedProduct(CheckedMultiplyOverflow)

A required limit product overflowed u64.



RowBytesBound

Per-conversation bytes are below N * B.

Fields

left: u64

Per-conversation row limit.

right: u64

Charged row byte bound.

checked_product: u64

Checked N * B product.

actual: u64

Configured per-conversation byte limit.



SdkBytesBound

SDK-wide bytes are below G * B.

Fields

left: u64

SDK-wide row limit.

right: u64

Charged row byte bound.

checked_product: u64

Checked G * B product.

actual: u64

Configured SDK-wide byte limit.



RecoverableSlots

Recoverable conversation slots exceed the connection capability.

Fields

actual: u64

Configured recoverable-conversation count.

limit: u64

Negotiated participant-conversation slots per connection.