SdkParkingCapacityIncompatible

Enum SdkParkingCapacityIncompatible 

pub enum SdkParkingCapacityIncompatible {
Show 18 variants NonzeroLimit { field: ParkingLimitField, actual: u64, required_minimum: u64, }, RecoveryEntrySchemaBytes { actual: u64, required: u64, }, WireSchemaBytes { actual: u64, required: u64, }, RequestSchemaBytes { configured_request_limit: u64, wire_frame_limit: u64, actual: u64, required: u64, }, RowSchemaBytes { request_limit: u64, row_metadata_bytes: u64, actual: u64, required: u128, }, CheckedProduct(CheckedMultiplyOverflow), RowBytesBound { left: u64, right: u64, checked_product: u64, actual: u64, }, SdkBytesBound { left: u64, right: u64, checked_product: u64, actual: u64, }, RecoverableSlots { actual: u64, limit: u64, }, ConversationRows { conversation_id: ConversationId, occupied: u64, limit: u64, }, ConversationBytes { conversation_id: ConversationId, occupied: u64, limit: u64, }, SdkConversations { occupied: u64, limit: u64, }, SdkRows { occupied: u64, limit: u64, }, SdkBytes { occupied: u64, limit: u64, }, RequestBytes { conversation_id: ConversationId, park_order: u64, actual: u64, limit: u64, }, RecoveryHandshakeRequestBytes { operands: HandshakeSizeOperands, limit: u64, }, RecoveryHandshakeRequestWireFrameBytes { operands: HandshakeSizeOperands, limit: u64, }, RecoveryHandshakeResponseWireFrameBytes { operands: HandshakeSizeOperands, limit: u64, },
}
Parked rows are incompatible with replacement SDK configuration.

Variants



NonzeroLimit

One of the replacement signed limits is zero.

Fields

field: ParkingLimitField

Offending signed field.

actual: u64

Actual value, which is zero for this variant.

required_minimum: u64

Required minimum, which is one for this variant.



RecoveryEntrySchemaBytes

Recovery request-entry schema is not the fixed width.

Fields

actual: u64

Configured request-entry width.

required: u64

Required request-entry width.



WireSchemaBytes

Wire frame is too small for one participant frame.

Fields

actual: u64

Configured wire-frame limit.

required: u64

Required participant-frame schema bytes.



RequestSchemaBytes

Effective request limit is too small for one request schema.

Fields

configured_request_limit: u64

Configured participant request limit.

wire_frame_limit: u64

Configured wire-frame limit.

actual: u64

Effective request limit min(R, WF).

required: u64

Required participant-request schema bytes.



RowSchemaBytes

Charged row bound is below request plus row metadata.

Fields

request_limit: u64

Configured participant request limit.

row_metadata_bytes: u64

Fixed row-metadata bytes.

actual: u64

Configured charged row byte bound.

required: u128

Exact widened required bytes.



CheckedProduct(CheckedMultiplyOverflow)

A required replacement limit product overflowed u64.



RowBytesBound

Per-conversation bytes are below N * B.

Fields

left: u64

Per-conversation row limit.

right: u64

Charged row byte bound.

checked_product: u64

Checked N * B product.

actual: u64

Configured per-conversation byte limit.



SdkBytesBound

SDK-wide bytes are below G * B.

Fields

left: u64

SDK-wide row limit.

right: u64

Charged row byte bound.

checked_product: u64

Checked G * B product.

actual: u64

Configured SDK-wide byte limit.



RecoverableSlots

Recoverable conversation slots exceed connection capability.

Fields

actual: u64

Configured recoverable-conversation count.

limit: u64

Negotiated participant-conversation slots per connection.



ConversationRows

Existing rows exceed replacement per-conversation row capacity.

Fields

conversation_id: ConversationId

Conversation with incompatible retained rows.

occupied: u64

Existing retained rows.

limit: u64

Replacement per-conversation row limit.



ConversationBytes

Existing bytes exceed replacement per-conversation byte capacity.

Fields

conversation_id: ConversationId

Conversation with incompatible retained bytes.

occupied: u64

Existing charged retained bytes.

limit: u64

Replacement per-conversation byte limit.



SdkConversations

Existing parked conversations exceed replacement SDK capacity.

Fields

occupied: u64

Existing parked-conversation count.

limit: u64

Replacement SDK conversation limit.



SdkRows

Existing rows exceed replacement SDK row capacity.

Fields

occupied: u64

Existing SDK-wide retained rows.

limit: u64

Replacement SDK row limit.



SdkBytes

Existing bytes exceed replacement SDK byte capacity.

Fields

occupied: u64

Existing SDK-wide charged retained bytes.

limit: u64

Replacement SDK byte limit.



RequestBytes

One retained request exceeds replacement effective request bytes.

Fields

conversation_id: ConversationId

Conversation holding the retained request.

park_order: u64

Durable order of the retained request.

actual: u64

Complete encoded participant request bytes.

limit: u64

Replacement effective request limit min(R, WF).



RecoveryHandshakeRequestBytes

Recovery request exceeds replacement participant request bytes.

Fields

operands: HandshakeSizeOperands

Complete exact widened sizing operands.

limit: u64

Replacement participant request limit.



RecoveryHandshakeRequestWireFrameBytes

Recovery request exceeds replacement wire-frame bytes.

Fields

operands: HandshakeSizeOperands

Complete exact widened sizing operands.

limit: u64

Replacement wire-frame limit.



RecoveryHandshakeResponseWireFrameBytes

Recovery response exceeds replacement wire-frame bytes.

Fields

operands: HandshakeSizeOperands

Complete exact widened sizing operands.

limit: u64

Replacement wire-frame limit.