pub enum AckNoOp {
ParticipantAck(ParticipantAckEnvelope),
MarkerAck(MarkerAckEnvelope),
}Expand description
Idempotent normal or marker acknowledgement.
Variants
ParticipantAck(ParticipantAckEnvelope)
Continuous acknowledgement.
MarkerAck(MarkerAckEnvelope)
Marker acknowledgement.
Implementations
Sourceimpl AckNoOp
impl AckNoOp
Sourcepub const fn participant_ack(request: ParticipantAckEnvelope) -> Self
pub const fn participant_ack(request: ParticipantAckEnvelope) -> Self
Constructs an idempotent continuous acknowledgement at its requested cursor.
Sourcepub const fn marker_ack(request: MarkerAckEnvelope) -> Self
pub const fn marker_ack(request: MarkerAckEnvelope) -> Self
Constructs an idempotent marker acknowledgement at its requested marker cursor.
Sourcepub const fn current_cursor(&self) -> DeliverySeq
pub const fn current_cursor(&self) -> DeliverySeq
Unchanged cursor, derived from the selected request envelope.