ObserverBackpressure

Enum ObserverBackpressure 

pub enum ObserverBackpressure {
    Enrollment {
        request: EnrollmentEnvelope,
        state: ObserverBackpressureState,
    },
    CredentialAttach {
        request: AttachEnvelope,
        state: ObserverBackpressureState,
    },
    Detach {
        request: DetachEnvelope,
        committed_binding_epoch: BindingEpoch,
        state: ObserverBackpressureState,
    },
    Leave {
        request: LeaveEnvelope,
        state: ObserverBackpressureState,
        prior_terminal_cell_exists: bool,
    },
    RecordAdmission {
        request: RecordAdmissionEnvelope,
        state: ObserverBackpressureState,
    },
}
Exact operation-specific observer-backpressure payload.

Variants



Enrollment

Enrollment.

Fields

request: EnrollmentEnvelope

Request envelope.

state: ObserverBackpressureState

Refusal state.



CredentialAttach

Credential attach.

Fields

request: AttachEnvelope

Request envelope.

state: ObserverBackpressureState

Refusal state.



Detach

Detach, which additionally exposes the committed old binding epoch.

Fields

request: DetachEnvelope

Request envelope.

committed_binding_epoch: BindingEpoch

Binding epoch the detach is terminalizing.

state: ObserverBackpressureState

Refusal state.



Leave

Leave, which additionally reports whether an older terminal cell exists.

Fields

request: LeaveEnvelope

Request envelope.

state: ObserverBackpressureState

Refusal state.

prior_terminal_cell_exists: bool

Whether an earlier terminal cell exists.



RecordAdmission

Ordinary admission.

Fields

request: RecordAdmissionEnvelope

Request envelope.

state: ObserverBackpressureState

Refusal state.