ServerDiscriminant

Enum ServerDiscriminant 

#[repr(u16)]
pub enum ServerDiscriminant {
Show 37 variants ParticipantTransportRejected = 256, AttemptTokenBodyConflict = 257, ConnectionConversationCapacityExceeded = 258, ConnectionConversationBindingOccupied = 259, ConversationOrderExhausted = 260, ParticipantUnknown = 261, NoBinding = 262, StaleAuthority = 263, Retired = 264, MarkerClosureCapacityExceeded = 265, EnrollBound = 266, EnrollmentKnown = 267, ReceiptExpired = 268, ReceiptCapacityExceeded = 269, IdentityCapacityExceeded = 270, ObserverBackpressure = 271, ConversationSequenceExhausted = 272, AttachBound = 273, StaleOrUnknownReceipt = 274, MarkerNotDelivered = 275, MarkerMismatch = 276, Bound = 277, UnboundReceipt = 278, DetachCommitted = 279, DetachInProgress = 280, AckCommitted = 281, AckNoOp = 282, AckGap = 283, AckRegression = 284, LeaveCommitted = 285, MarkerAckCommitted = 286, RecordCommitted = 287, RecordTooLarge = 288, ObserverRecoveryAccepted = 289, InvalidObserverEpoch = 290, InvalidObserverEpochList = 291, ObserverRecoveryConnectionCapacityExceeded = 292,
}
Server-to-client semantic participant value registry.

Variants



ParticipantTransportRejected = 256

Pre-semantic structural/authentication rejection.



AttemptTokenBodyConflict = 257

A token was reused with a changed canonical body.



ConnectionConversationCapacityExceeded = 258

Connection conversation capacity was exhausted.



ConnectionConversationBindingOccupied = 259

The connection’s conversation binding slot was occupied.



ConversationOrderExhausted = 260

Transaction order was exhausted.



ParticipantUnknown = 261

Presented participant identity does not exist.



NoBinding = 262

Valid identity has no required binding.



StaleAuthority = 263

Presented authority is stale.



Retired = 264

Presented identity is permanently retired.



MarkerClosureCapacityExceeded = 265

Marker-closure capacity or recovery fence refused admission.



EnrollBound = 266

Enrollment committed and bound.



EnrollmentKnown = 267

Enrollment token maps to an existing live identity.



ReceiptExpired = 268

Stored receipt expired or was superseded.



ReceiptCapacityExceeded = 269

Receipt/provenance capacity was exhausted.



IdentityCapacityExceeded = 270

Participant identity capacity was exhausted.



ObserverBackpressure = 271

Observer progress prevents the mutation.



ConversationSequenceExhausted = 272

Conversation sequence reserve was exhausted.



AttachBound = 273

Credential attach committed and bound.



StaleOrUnknownReceipt = 274

Receipt is stale or no longer known.



MarkerNotDelivered = 275

Requested marker was not delivered to the proof epoch.



MarkerMismatch = 276

Presented marker does not match current marker state.



Bound = 277

Receipt replay still names the current binding.



UnboundReceipt = 278

Receipt replay no longer names the current binding.



DetachCommitted = 279

Explicit detach committed.



DetachInProgress = 280

Another detach token is pending.



AckCommitted = 281

Continuous acknowledgement advanced the cursor.



AckNoOp = 282

Acknowledgement was an idempotent no-op.



AckGap = 283

Continuous acknowledgement crossed an unavailable gap.



AckRegression = 284

Continuous acknowledgement regressed below the cursor.



LeaveCommitted = 285

Terminal Leave committed.



MarkerAckCommitted = 286

Marker acknowledgement committed.



RecordCommitted = 287

Ordinary record committed.



RecordTooLarge = 288

Ordinary record exceeded its configured maximum.



ObserverRecoveryAccepted = 289

Observer-recovery batch succeeded.



InvalidObserverEpoch = 290

Observer-recovery entry has an invalid epoch.



InvalidObserverEpochList = 291

Observer-recovery request list is invalid.



ObserverRecoveryConnectionCapacityExceeded = 292

Observer-recovery preflight exceeded connection capacity.

Implementations

Source

impl ServerDiscriminant

pub const fn wire_value(self) -> u16

Returns the stable v1 wire value.