pub struct DetachCommitted { /* private fields */ }Expand description
Stable committed detach response.
Implementations
Sourceimpl DetachCommitted
impl DetachCommitted
Sourcepub const fn new(
conversation_id: ConversationId,
participant_id: ParticipantId,
detach_attempt_token: DetachAttemptToken,
committed_binding_epoch: BindingEpoch,
detached_delivery_seq: DeliverySeq,
) -> Self
pub const fn new( conversation_id: ConversationId, participant_id: ParticipantId, detach_attempt_token: DetachAttemptToken, committed_binding_epoch: BindingEpoch, detached_delivery_seq: DeliverySeq, ) -> Self
Constructs a detach result and derives its presented generation from the binding epoch it ended.
Sourcepub const fn conversation_id(&self) -> ConversationId
pub const fn conversation_id(&self) -> ConversationId
Conversation from the request.
Sourcepub const fn participant_id(&self) -> ParticipantId
pub const fn participant_id(&self) -> ParticipantId
Participant from the request.
Sourcepub const fn capability_generation(&self) -> Generation
pub const fn capability_generation(&self) -> Generation
Presented generation, equal to the committed binding epoch generation.
Sourcepub const fn detach_attempt_token(&self) -> DetachAttemptToken
pub const fn detach_attempt_token(&self) -> DetachAttemptToken
Committed detach token.
Sourcepub const fn committed_binding_epoch(&self) -> BindingEpoch
pub const fn committed_binding_epoch(&self) -> BindingEpoch
Binding epoch ended by detach.
Sourcepub const fn detached_delivery_seq(&self) -> DeliverySeq
pub const fn detached_delivery_seq(&self) -> DeliverySeq
Assigned Detached delivery sequence.