pub struct DetachTransportAttempt { /* private fields */ }Expand description
Sealed effect authorizing one transport send of the exact detach.
Implementations
Sourceimpl DetachTransportAttempt
impl DetachTransportAttempt
Sourcepub const fn request(&self) -> &DetachEnvelope
pub const fn request(&self) -> &DetachEnvelope
Borrows the exact detach to send.
Sourcepub const fn into_request(self) -> (DetachEnvelope, ClientResponseCorrelation)
pub const fn into_request(self) -> (DetachEnvelope, ClientResponseCorrelation)
Consumes this one-use send effect into the exact wire envelope and its lifecycle correlation. The correlation must be consumed by outcome, transport fate, or typed abandonment before another attempt can start.