MarkerAckCommitError

Enum MarkerAckCommitError 

pub enum MarkerAckCommitError {
    Conversation {
        expected: ConversationId,
        actual: ConversationId,
    },
    Participant {
        expected: ParticipantId,
        actual: ParticipantId,
    },
    Generation {
        expected: Generation,
        actual: Generation,
    },
    NonAdvancing {
        from_cursor: DeliverySeq,
        resulting_cursor: DeliverySeq,
    },
    CursorPrestate {
        expected_from_cursor: DeliverySeq,
        resulting_cursor: DeliverySeq,
        actual_cursor: DeliverySeq,
    },
}
Failure while applying an already-selected marker-ack commit.

Variants



Conversation

Commit belongs to another conversation.

Fields

expected: ConversationId

Conversation captured by the commit.

actual: ConversationId

Conversation carried by the supplied member.



Participant

Commit belongs to another participant.

Fields

expected: ParticipantId

Participant captured by the commit.

actual: ParticipantId

Participant carried by the supplied member.



Generation

Commit belongs to another credential generation.

Fields

expected: Generation

Generation captured by the commit.

actual: Generation

Generation carried by the supplied member.



NonAdvancing

A malformed internal update did not strictly advance its source cursor.

Fields

from_cursor: DeliverySeq

Cursor from which the update was selected.

resulting_cursor: DeliverySeq

Proposed resulting cursor.



CursorPrestate

Supplied member is neither the exact old nor exact committed prestate.

Fields

expected_from_cursor: DeliverySeq

Cursor from which the commit was selected.

resulting_cursor: DeliverySeq

Cursor produced by the commit.

actual_cursor: DeliverySeq

Cursor carried by the supplied member.