apply_attach_frontier

Function apply_attach_frontier 

pub fn apply_attach_frontier<F, V>(
    owner: LiveFrontierOwner,
    operation: AttachCommit<F, V>,
    charges: AttachFrontierCharges,
) -> LiveFrontierResult<AttachCommit<F, V>>
Applies credential attach to the complete live owner.

Errors

Returns a failure retaining the unchanged owner, intact attach commit, and exact reason the commit could not enter the frontier.