FrontierParticipant

Struct FrontierParticipant 

pub struct FrontierParticipant { /* private fields */ }
Participant-indexed membership fact used by claim validation and planning.

Implementations

Source

impl FrontierParticipant

pub const fn new( participant_index: ParticipantId, cursor: DeliverySeq, binding: FrontierBinding, ) -> Self

Creates one exact live-membership frontier fact.

pub const fn participant_index(self) -> ParticipantId

Returns the permanent participant index.

pub const fn cursor(self) -> DeliverySeq

Returns the durable cumulative cursor.

pub const fn binding(self) -> FrontierBinding

Returns the exact current or last authoritative binding state.