pub enum ParkingShapeViolation {
NonzeroLimit {
field: ParkingLimitField,
actual: u64,
required_minimum: u64,
},
RecoveryEntrySchemaBytes {
actual: u64,
required: u64,
},
WireSchemaBytes {
actual: u64,
required: u64,
},
RequestSchemaBytes {
configured_request_limit: u64,
wire_frame_limit: u64,
actual: u64,
required: u64,
},
RowSchemaBytes {
request_limit: u64,
row_metadata_bytes: u64,
actual: u64,
required: u128,
},
CheckedProduct(CheckedMultiplyOverflow),
RowBytesBound {
left: u64,
right: u64,
checked_product: u64,
actual: u64,
},
SdkBytesBound {
left: u64,
right: u64,
checked_product: u64,
actual: u64,
},
RecoverableSlots {
actual: u64,
limit: u64,
},
}Expand description
Exact nine-way parking configuration-shape violation.
Variants
NonzeroLimit
One of the signed limits is zero.
Fields

field: ParkingLimitFieldOffending signed field.
RecoveryEntrySchemaBytes
Recovery request-entry schema is not the fixed width.
Fields
WireSchemaBytes
Wire frame is too small for one participant frame.
Fields
RequestSchemaBytes
Effective request limit is too small for one request schema.
Fields
RowSchemaBytes
Charged row bound is below request plus row metadata.
Fields
CheckedProduct(CheckedMultiplyOverflow)
A required limit product overflowed u64.
RowBytesBound
Per-conversation bytes are below N * B.
Fields
SdkBytesBound
SDK-wide bytes are below G * B.
Fields
RecoverableSlots
Recoverable conversation slots exceed the connection capability.